@@ -2,7 +2,7 @@
 #' 
 #' Stepwise Cox regression analysis selects model based on information criteria and significant test with 'forward', 'backward', 'bidirection' and 'score' variable selection method.
 #' 
-#' @param formula Model formulae. The models fitted by the coxph functions are specified in a compact symbolic form. The basic structure of a formula is the tilde symbol (~) and at least one independent (righthand) variable. In most (but not all) situations, a single dependent (lefthand) variable is also needed. Thus we can construct a formula quite simple formula (y ~ x). Multiple independent variables by simply separating them with the plus (+) symbol (y ~ x1 + x2). Variables in the formula are removed with a minus(-) symbol (y ~ x1 - x2). One particularly useful feature is the . operator when modelling with lots of variables (y ~ .). The %in% operator indicates that the terms on its left are nested within those on the right. For example y ~ x1 + x2 %in% x1 expands to the formula y ~ x1 + x1:x2.
+#' @param formula Model formulae. The models fitted by the coxph functions are specified in a compact symbolic form. The basic structure of a formula is the tilde symbol (~) and at least one independent (righthand) variable. In most (but not all) situations, a single dependent (lefthand) variable is also needed. Thus we can construct a formula quite simple formula (y ~ x). Multiple independent variables by simply separating them with the plus (+) symbol (y ~ x1 + x2). Variables in the formula are removed with a minus(-) symbol (y ~ x1 - x2). One particularly useful feature is the . operator when modelling with lots of variables (y ~ .). The \%in\% operator indicates that the terms on its left are nested within those on the right. For example y ~ x1 + x2 \%in\% x1 expands to the formula y ~ x1 + x1:x2.
 #' 
 #' @param data Data set including dependent and independent variables to be analyzed
 #' 
@@ -63,20 +63,15 @@
 #' my.data <- na.omit(lung)
 #' my.data$status1 <- ifelse(my.data$status==2,1,0)
 #' data <- my.data
-#' formula = Surv(time, status1) ~ . - status
+#' formula = Surv(time, status1) ~ . - status 
 #' 
-#' stepwiseCox(formula,
-#' data,
-#' include=NULL,
-#' selection=c("bidirection"),
+#' stepwiseCox(formula=formula,
+#' data=my.data,
+#' selection="bidirection",
 #' select="HQ",
-#' method=c("efron"),
-#' sle=0.15,
-#' sls=0.15,
-#' weights=NULL,
-#' best=NULL)
+#' method="efron")
 #' 
-#' @export stepwiseCox
+#' @export
 
 stepwiseCox <- function(formula,
                         data,
@@ -110,14 +105,13 @@ stepwiseCox <- function(formula,
     stop("include should be character vector indicating variable to be included in all models")
   }
   fmFull <- reformulate(c(xName),yName)
-  fitFull <- coxph(fmFull,data=data, weights=weights,method=method)
+  fitFull <- survival::coxph(fmFull,data=data, weights=weights,method=method)
   allVarClass <- attr(fitFull$terms,"dataClasses")
   classTable <- as.data.frame(table(allVarClass))
   colnames(classTable) <- c("class","variable")
   for(i in names(table(allVarClass))){
     classTable[names(table(allVarClass)) %in% i,2] <- paste0(names(allVarClass[allVarClass %in% i]),collapse=" ")
   }
-  classTable$class <- paste0(classTable$class,":")
   ## detect multicollinearity
   if(any(allVarClass=="factor")){
     factVar <- names(which(allVarClass=="factor"))
@@ -142,15 +136,15 @@ stepwiseCox <- function(formula,
   ModInf <- matrix(NA,8,1)
   ModInf <- cbind(ModInf,matrix(c(yName,mergeIncName,selection,select,sle,sle,method,mulcolMergeName),8,1))
   ModInf <- data.frame(ModInf)
-  colnames(ModInf) <- c("","")
-  ModInf[,1] <- c("Response Variable = ",
-                  "Included Variable = ",
-                  "Selection Method = ",
-                  "Select Criterion = ",
-                  "Entry Significance Level(sle) = ",
-                  "Stay Significance Level(sls) = ",
-                  "Multicollinearity Terms = ",
-                  "Method = ")
+  colnames(ModInf) <- c("Paramters","Value")
+  ModInf[,1] <- c("Response Variable",
+                  "Included Variable",
+                  "Selection Method",
+                  "Select Criterion",
+                  "Entry Significance Level(sle)",
+                  "Stay Significance Level(sls)",
+                  "Method",
+                  "Multicollinearity Terms")
   if(select=="SL"){
     if(selection=="forward"){
       ModInf <- ModInf[-6,]
@@ -163,8 +157,8 @@ stepwiseCox <- function(formula,
     ModInf <- ModInf[-c(5:6),]
   }
   rownames(ModInf) <- 1:nrow(ModInf)
-  result$'Basic Information' <- ModInf
-  result$'Variable Class' <- classTable
+  result$'Summary of Parameters' <- ModInf
+  result$'Variables Type' <- classTable
   if(selection=="score"){ #score
     bestSubSet <- NULL
     singSet <- matrix(NA,1,3)
@@ -172,7 +166,7 @@ stepwiseCox <- function(formula,
     finalResult <- singSet
     if(length(includeName)!=0){
       fm <- reformulate(c(includeName), yName)
-      fit <- coxph(fm,data=data, weights=weights,method=method)
+      fit <- survival::coxph(fm,data=data, weights=weights,method=method)
       if(select=="SL"){
         #PIC <- summary(fit)[[sigMethod]][1]
         PIC <- fit$score
@@ -192,7 +186,7 @@ stepwiseCox <- function(formula,
       for(ncom in 1:ncol(comTable)){
         comVar <- c(includeName,comTable[,ncom])
         fm <- reformulate(comVar, yName)
-        fit <- coxph(fm,data = data,weights=weights,method=method)
+        fit <- survival::coxph(fm,data = data,weights=weights,method=method)
         if(select=="SL"){
           PIC <- fit$score
         }else{
@@ -222,7 +216,12 @@ stepwiseCox <- function(formula,
     finalResult <- finalResult[-1,]
     RegPIC <- rbind(includeSubSet,finalResult)
     rownames(RegPIC) <- c(1:nrow(RegPIC))
-    result$Process <- RegPIC
+    result$'Process of Selection' <- RegPIC
+    if(select=="SL"){
+      xModel <- unlist(strsplit(RegPIC[which.max(as.numeric(RegPIC[,2])),3]," "))
+    }else{
+      xModel <- unlist(strsplit(RegPIC[which.min(as.numeric(RegPIC[,2])),3]," "))
+    }
   }else{ #forward # bidirection # backward
     subBestPoint <- data.frame(Step=numeric(),
                                EnteredEffect=character(),
@@ -237,7 +236,7 @@ stepwiseCox <- function(formula,
       xModel <- c(includeName,setdiff(xName,includeName))
       xResidual <- NULL
       fmFull <- reformulate(xModel, yName)
-      fitFull <- coxph(fmFull,data=data,weights=weights,method=method)
+      fitFull <- survival::coxph(fmFull,data=data,weights=weights,method=method)
       if(select=="SL"){
         PIC <- 1
       }else{
@@ -257,11 +256,11 @@ stepwiseCox <- function(formula,
       bestPoint[1,] <- c(0,"","",0,0,PIC)
       if(!is.null(includeName)){
         fmInt <- reformulate("0",yName)
-        fitInt <- coxph(fmInt,data=data,weights=weights,method=method)
+        fitInt <- survival::coxph(fmInt,data=data,weights=weights,method=method)
         fmInc <- reformulate(includeName,yName)
-        fitInc <- coxph(fmInc,data=data,weights=weights,method=method)
+        fitInc <- survival::coxph(fmInc,data=data,weights=weights,method=method)
         if(select=="SL"){
-          PIC <- anova(fitInt,fitInc)[2,'P(>|Chi|)']
+          PIC <- anova(fitInt,fitInc)[2,'Pr(>|Chi|)']
         }else{
           PIC <- modelFitStat(select,fitInc,"Likelihood",TRUE)
         }
@@ -278,17 +277,17 @@ stepwiseCox <- function(formula,
           xMod <- xModel
         }
         fm0 <- reformulate(xMod, yName)
-        fit0 <- coxph(fm0,data = data,weights=weights,method=method)
-		if(length(xResidual)==0){
-		  break
-		}
+        fit0 <- survival::coxph(fm0,data = data,weights=weights,method=method)
+        if(length(xResidual)==0){
+          break
+        }
         xResidualList <- as.list(xResidual)
         names(xResidualList) <- xResidual
         fm1 <- lapply(xResidualList,function(x){reformulate(c(xModel,x),yName)})
-        fit1 <- lapply(fm1,function(x){coxph(x,data = data,weights=weights,method=method)})
+        fit1 <- lapply(fm1,function(x){survival::coxph(x,data = data,weights=weights,method=method)})
         if(select=="SL"){
           threshold <- sle
-          PICset <- sapply(fit1,function(x){anova(fit0,x)[2,'P(>|Chi|)']})
+          PICset <- sapply(fit1,function(x){anova(fit0,x)[2,'Pr(>|Chi|)']})
         }else{
           threshold <- as.numeric(bestPoint[nrow(bestPoint),6])
           PICset <- sapply(fit1,function(x){modelFitStat(select,x,"Likelihood",TRUE)})
@@ -308,7 +307,7 @@ stepwiseCox <- function(formula,
         }
       }else{
         fm1 <- reformulate(xModel,yName)
-        fit1 <- coxph(fm1,data=data,weights=weights,method=method)
+        fit1 <- survival::coxph(fm1,data=data,weights=weights,method=method)
         xChcek <- setdiff(xModel,c(includeName))
         if(is.null(xChcek)){
           break
@@ -320,10 +319,10 @@ stepwiseCox <- function(formula,
           names(xChcekList) <- xChcek
           fm0 <- lapply(xChcekList,function(x){reformulate(setdiff(xModel,x),yName)})
         }
-        fit0 <- lapply(fm0,function(x){coxph(x,data=data,weights=weights,method=method)})
+        fit0 <- lapply(fm0,function(x){survival::coxph(x,data=data,weights=weights,method=method)})
         if(select=="SL"){
           threshold <- sls
-          PIC <- sapply(fit0,function(x){anova(x,fit1)[2,'P(>|Chi|)']})
+          PIC <- sapply(fit0,function(x){anova(x,fit1)[2,'Pr(>|Chi|)']})
           mPIC <- max(PIC)
           minmaxVar <- names(which.max(PIC))
           if(mPIC > threshold){
@@ -387,13 +386,17 @@ stepwiseCox <- function(formula,
     }else{
       bestPoint[,1] <- c(1:nrow(bestPoint)-1)
     }
-    
-    lastModel <- reformulate(xModel,yName)
-    lastFit <- coxph(lastModel,data,weights=weights,method=method)
-    MLE <- coef(summary(lastFit))
-    result$Process <- bestPoint
-    result$Variables <- xModel
-    result$Coefficients <- MLE
+    result$'Process of Selection' <- bestPoint
   }
+  lastModel <- reformulate(xModel,yName)
+  lastFit <- survival::coxph(lastModel,data,weights=weights,method=method)
+  MLE <- coef(summary(lastFit))
+  MLE <- as.data.frame(cbind(rownames(MLE),MLE))
+  colnames(MLE)[1] <- c("Variable")
+  variables <- as.data.frame(t(data.frame(xModel)))
+  colnames(variables) <- paste0("variables",1:length(xModel))
+  result$'Selected Varaibles' <- variables
+  result$'Coefficients of the Selected Variables' <- MLE
+  class(result) <- c("StepReg","list")
   return(result)
-}
\ No newline at end of file
+}
